% This file is part of the OPTPDE problem collection
%                 http://www.optpde.net
% It is provided as is, without any warranty, under the 
%
% Creative Commons Attribution-NonCommercial ShareAlike 4.0 International
%
%         http://creativecommons.org/licenses/by-nc-sa/4.0/
%
% Please give proper credits when using this file by referencing the 
% collection. For this purpose detailed bibliography data is 
% available at the collections website 
%                  
%                 http://www.optpde.net
%
% This file contains data for the benchmark problem 
%                      mpdist3
% from  2022-04-01 


% setup the problem
problem = setup_problem;

% generate a grid on the domain
[x1,x2] = meshgrid(linspace(-1,1,41),linspace(-1,1,41));
t = 0;

% plot the desired state component 1 at time t = 0
figure(1); clf; hold on
val = vd1(problem,x1,x2,t);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title(sprintf('desired state vd_1 at time t = %.2f',t));
view(3);

% plot the desired state component 2 at time t = 0
figure(2); clf; hold on
val = vd2(problem,x1,x2,t);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title(sprintf('desired state vd_2 at time t = %.2f',t));
view(3);

% plot the force component 1 at time t = 0
figure(3); clf; hold on
val = z1(problem,x1,x2,t);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title(sprintf('uncontrolled force z_1 at time t = %.2f',t));
view(3);

% plot the force component 2 at time t = 0
figure(4); clf; hold on
val = z2(problem,x1,x2,t);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title(sprintf('uncontrolled force z_2 at time t = %.2f',t));
view(3);

% plot the initial state component 1
figure(5); clf; hold on
val = v01(problem,x1,x2);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title('initial state v0_1');
view(3);

% plot the initial state component 2
figure(6); clf; hold on
val = v02(problem,x1,x2);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title('initial state v0_2');
view(3);

% plot the optimal velocity component 1 at time t = 0
figure(7); clf; hold on
val = supplementary_v1(problem,x1,x2,t);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title(sprintf('optimal velocity v_1 at time t = %.2f',t));
view(3);

% plot the optimal velocity component 2 at time t = 0
figure(8); clf; hold on
val = supplementary_v2(problem,x1,x2,t);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title(sprintf('optimal velocity v_2 at time t = %.2f',t));
view(3);

% plot the optimal pressure at time t = 0
figure(9); clf; hold on
val = supplementary_p(problem,x1,x2,t);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title(sprintf('optimal pressure p at time t = %.2f',t));
view(3);

% plot the optimal adjoint velocity component 1 at time t = 0
figure(10); clf; hold on
val = supplementary_lambda1(problem,x1,x2,t);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title(sprintf('optimal adjoint velocity lambda_1 at time t = %.2f',t));
view(3);

% plot the optimal adjoint velocity component 2 at time t = 0
figure(11); clf; hold on
val = supplementary_lambda2(problem,x1,x2,t);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title(sprintf('optimal adjoint velocity lambda_2 at time t = %.2f',t));
view(3);

% plot the optimal adjoint pressure at time t = 0
figure(12); clf; hold on
val = supplementary_mu(problem,x1,x2,t);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title(sprintf('optimal adjoint pressure mu at time t = %.2f',t));
view(3);

% plot the optimal control component 1 at time t = 0
figure(13); clf; hold on
val = supplementary_u1(problem,x1,x2,t);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title(sprintf('optimal control u_1 at time t = %.2f',t));
view(3);

% plot the optimal control component 2 at time t = 0
figure(14); clf; hold on
val = supplementary_u2(problem,x1,x2,t);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title(sprintf('optimal control u_2 at time t = %.2f',t));
view(3);

